@@ -1,7 +1,7 @@
 package Bencher::Scenario::AcmePERLANCARTestPerformance;
 
 our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -34,7 +34,7 @@ Bencher::Scenario::AcmePERLANCARTestPerformance - Benchmark Acme::PERLANCAR::Tes
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::AcmePERLANCARTestPerformance (from Perl distribution Bencher-Scenario-AcmePERLANCARTestPerformance), released on 2017-01-25.
+This document describes version 0.05 of Bencher::Scenario::AcmePERLANCARTestPerformance (from Perl distribution Bencher-Scenario-AcmePERLANCARTestPerformance), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -90,12 +90,12 @@ Benchmark with C<< bencher -m AcmePERLANCARTestPerformance --include-path /home/
  +--------+-----------+-----------+------------+---------+---------+
  | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +--------+-----------+-----------+------------+---------+---------+
- | 0.01   |       639 |    1.56   |       1    | 2.1e-07 |      21 |
- | 0.02   |      2830 |    0.354  |       4.42 | 5.1e-08 |      22 |
- | 0.03   |      3610 |    0.277  |       5.64 | 2.5e-07 |      22 |
- | 0.04   |     78000 |    0.013  |     120    | 2.7e-08 |      20 |
- | 0.05   |     78000 |    0.013  |     120    |   2e-08 |      35 |
- | 0.06   |     79100 |    0.0126 |     124    | 6.1e-09 |      24 |
+ | 0.01   |    543    | 1.84      |    1       | 2.7e-07 |      20 |
+ | 0.02   |   2816.48 | 0.355053  |    5.18631 | 5.7e-11 |      20 |
+ | 0.03   |   4045.69 | 0.247177  |    7.44979 | 7.3e-11 |      20 |
+ | 0.05   |  78036.3  | 0.0128145 |  143.697   |   0     |      20 |
+ | 0.06   |  78300    | 0.0128    |  144       | 6.4e-09 |      22 |
+ | 0.04   |  78400    | 0.0128    |  144       | 4.8e-09 |      38 |
  +--------+-----------+-----------+------------+---------+---------+
 
 
@@ -105,13 +105,13 @@ Benchmark with C<< bencher -m AcmePERLANCARTestPerformance --include-path /home/
  +------------------------------------+--------+-----------+------------------------+------------+---------+---------+
  | participant                        | modver | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +------------------------------------+--------+-----------+------------------------+------------+---------+---------+
- | Acme::PERLANCAR::Test::Performance | 0.06   |       4.9 |                    3.2 |        1   | 1.7e-05 |      20 |
- | Acme::PERLANCAR::Test::Performance | 0.02   |       4.9 |                    3.2 |        1   | 1.6e-05 |      20 |
- | Acme::PERLANCAR::Test::Performance | 0.03   |       4.8 |                    3.1 |        1   | 2.3e-05 |      20 |
- | Acme::PERLANCAR::Test::Performance | 0.05   |       4.7 |                    3   |        1   | 1.8e-05 |      20 |
- | Acme::PERLANCAR::Test::Performance | 0.01   |       4.7 |                    3   |        1.1 | 2.4e-05 |      20 |
- | Acme::PERLANCAR::Test::Performance | 0.04   |       4.7 |                    3   |        1.1 | 1.9e-05 |      20 |
- | perl -e1 (baseline)                |        |       1.7 |                    0   |        2.9 | 9.4e-06 |      20 |
+ | Acme::PERLANCAR::Test::Performance | 0.06   |       4.9 |                    3.2 |        1   | 1.5e-05 |      20 |
+ | Acme::PERLANCAR::Test::Performance | 0.04   |       4.8 |                    3.1 |        1   |   2e-05 |      21 |
+ | Acme::PERLANCAR::Test::Performance | 0.01   |       4.8 |                    3.1 |        1   | 2.5e-05 |      20 |
+ | Acme::PERLANCAR::Test::Performance | 0.05   |       4.8 |                    3.1 |        1   | 3.4e-05 |      21 |
+ | Acme::PERLANCAR::Test::Performance | 0.02   |       4.7 |                    3   |        1.1 | 2.1e-05 |      21 |
+ | Acme::PERLANCAR::Test::Performance | 0.03   |       4.7 |                    3   |        1.1 |   4e-05 |      20 |
+ | perl -e1 (baseline)                |        |       1.7 |                    0   |        2.9 | 1.1e-05 |      20 |
  +------------------------------------+--------+-----------+------------------------+------------+---------+---------+
 
 
