@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::AcmePERLANCARTestPerformance;
 
-our $VERSION = 0.04; # VERSION
+our $VERSION = 0.05; # VERSION
 
 our $results = [
   [
@@ -8,52 +8,52 @@ our $results = [
     "OK",
     [
       {
-        errors     => 2.1e-07,
+        errors     => 2.7e-07,
         modver     => 0.01,
-        rate       => 639,
-        samples    => 21,
-        time       => 1.56,
+        rate       => 543,
+        samples    => 20,
+        time       => 1.84,
         vs_slowest => 1,
       },
       {
-        errors     => 5.1e-08,
+        errors     => 5.7e-11,
         modver     => 0.02,
-        rate       => 2830,
-        samples    => 22,
-        time       => 0.354,
-        vs_slowest => 4.42,
-      },
-      {
-        errors     => 2.5e-07,
-        modver     => 0.03,
-        rate       => 3610,
-        samples    => 22,
-        time       => 0.277,
-        vs_slowest => 5.64,
-      },
-      {
-        errors     => 2.7e-08,
-        modver     => 0.04,
-        rate       => 78000,
+        rate       => 2816.48,
         samples    => 20,
-        time       => 0.013,
-        vs_slowest => 120,
+        time       => 0.355053,
+        vs_slowest => 5.18631,
       },
       {
-        errors     => 2e-08,
+        errors     => 7.3e-11,
+        modver     => 0.03,
+        rate       => 4045.69,
+        samples    => 20,
+        time       => 0.247177,
+        vs_slowest => 7.44979,
+      },
+      {
+        errors     => 0,
         modver     => 0.05,
-        rate       => 78000,
-        samples    => 35,
-        time       => 0.013,
-        vs_slowest => 120,
+        rate       => 78036.3,
+        samples    => 20,
+        time       => 0.0128145,
+        vs_slowest => 143.697,
       },
       {
-        errors     => 6.1e-09,
+        errors     => 6.4e-09,
         modver     => 0.06,
-        rate       => 79100,
-        samples    => 24,
-        time       => 0.0126,
-        vs_slowest => 124,
+        rate       => 78300,
+        samples    => 22,
+        time       => 0.0128,
+        vs_slowest => 144,
+      },
+      {
+        errors     => 4.8e-09,
+        modver     => 0.04,
+        rate       => 78400,
+        samples    => 38,
+        time       => 0.0128,
+        vs_slowest => 144,
       },
     ],
     {
@@ -185,7 +185,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2615.593,
+                                              speed                        => 2852.992,
                                               stepping                     => 4,
                                             },
                                             {
@@ -300,7 +300,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2806.562,
+                                              speed                        => 2866.828,
                                               stepping                     => 4,
                                             },
                                             {
@@ -415,7 +415,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2756.468,
+                                              speed                        => 2665.742,
                                               stepping                     => 4,
                                             },
                                             {
@@ -530,12 +530,13 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2853.265,
+                                              speed                        => 2684.992,
                                               stepping                     => 4,
                                             },
                                           ],
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Acme::PERLANCAR::Test::Performance" => 0.06,
                                             "Bencher::Scenario::AcmePERLANCARTestPerformance" => undef,
                                             "Benchmark::Dumb" => "0.10",
@@ -548,7 +549,7 @@ our $results = [
                                             "perl",
                                             ["perl"],
                                             "modver",
-                                            [0.03, 0.05, 0.06, 0.04, 0.01, 0.02],
+                                            [0.04, 0.01, 0.02, 0.06, 0.05, 0.03],
                                             "participant",
                                             [0],
                                             "dataset",
@@ -584,7 +585,7 @@ our $results = [
       "func.scenario_module_sha1sum"   => "cdcd801414f022536e2d725e930f5b81bdb9396d",
       "func.scenario_module_sha256sum" => "76adffe99901059cabb68a114e612d246729b64c2d1c3287622df53c790227f3",
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485312859.81277,
+      "func.time_start"                => 1485317229.73415,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "ms"],
       "table.fields"                   => ["modver", "rate", "time", "vs_slowest", "errors", "samples"],
@@ -595,7 +596,7 @@ our $results = [
     "OK",
     [
       {
-        errors => 1.7e-05,
+        errors => 1.5e-05,
         mod_overhead_time => 3.2,
         modver => 0.06,
         participant => "Acme::PERLANCAR::Test::Performance",
@@ -604,52 +605,52 @@ our $results = [
         vs_slowest => 1,
       },
       {
-        errors => 1.6e-05,
-        mod_overhead_time => 3.2,
-        modver => 0.02,
+        errors => 2e-05,
+        mod_overhead_time => 3.1,
+        modver => 0.04,
         participant => "Acme::PERLANCAR::Test::Performance",
-        samples => 20,
-        time => 4.9,
+        samples => 21,
+        time => 4.8,
         vs_slowest => 1,
       },
       {
-        errors => 2.3e-05,
+        errors => 2.5e-05,
         mod_overhead_time => 3.1,
-        modver => 0.03,
+        modver => 0.01,
         participant => "Acme::PERLANCAR::Test::Performance",
         samples => 20,
         time => 4.8,
         vs_slowest => 1,
       },
       {
-        errors => 1.8e-05,
-        mod_overhead_time => 3,
+        errors => 3.4e-05,
+        mod_overhead_time => 3.1,
         modver => 0.05,
         participant => "Acme::PERLANCAR::Test::Performance",
-        samples => 20,
-        time => 4.7,
+        samples => 21,
+        time => 4.8,
         vs_slowest => 1,
       },
       {
-        errors => 2.4e-05,
+        errors => 2.1e-05,
         mod_overhead_time => 3,
-        modver => 0.01,
+        modver => 0.02,
+        participant => "Acme::PERLANCAR::Test::Performance",
+        samples => 21,
+        time => 4.7,
+        vs_slowest => 1.1,
+      },
+      {
+        errors => 4e-05,
+        mod_overhead_time => 3,
+        modver => 0.03,
         participant => "Acme::PERLANCAR::Test::Performance",
         samples => 20,
         time => 4.7,
         vs_slowest => 1.1,
       },
       {
-        errors => 1.9e-05,
-        mod_overhead_time => 3,
-        modver => 0.04,
-        participant => "Acme::PERLANCAR::Test::Performance",
-        samples => 20,
-        time => 4.7,
-        vs_slowest => 1.1,
-      },
-      {
-        errors => 9.4e-06,
+        errors => 1.1e-05,
         mod_overhead_time => 0,
         modver => "",
         participant => "perl -e1 (baseline)",
@@ -788,7 +789,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2865.351,
+                                              speed                        => 2620.953,
                                               stepping                     => 4,
                                             },
                                             {
@@ -903,7 +904,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2728.906,
+                                              speed                        => "2861.960",
                                               stepping                     => 4,
                                             },
                                             {
@@ -1018,7 +1019,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2887.664,
+                                              speed                        => 2794.585,
                                               stepping                     => 4,
                                             },
                                             {
@@ -1133,12 +1134,13 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2658.687,
+                                              speed                        => "2743.070",
                                               stepping                     => 4,
                                             },
                                           ],
       "func.module_startup"            => 1,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Acme::PERLANCAR::Test::Performance" => 0.06,
                                             "Bencher::Scenario::AcmePERLANCARTestPerformance" => undef,
                                             "Benchmark::Dumb" => "0.10",
@@ -1151,7 +1153,7 @@ our $results = [
                                             "perl",
                                             ["perl"],
                                             "modver",
-                                            [0.02, 0.04, 0.01, 0.06, 0.05, 0.03],
+                                            [0.02, 0.01, 0.04, 0.06, 0.03, 0.05],
                                             "participant",
                                             [0, 1],
                                           ],
@@ -1185,7 +1187,7 @@ our $results = [
       "func.scenario_module_sha1sum"   => "cdcd801414f022536e2d725e930f5b81bdb9396d",
       "func.scenario_module_sha256sum" => "76adffe99901059cabb68a114e612d246729b64c2d1c3287622df53c790227f3",
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485312860.73081,
+      "func.time_start"                => 1485317230.64564,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "ms", "ms"],
       "table.fields"                   => [
